@@ -3,13 +3,14 @@
 # slim.dantzig.ladm.scr(): Regression with Dantzig()                               #
 # Author: Xingguo Li                                                               #
 # Email: <xingguo.leo@gmail.com>                                                   #
-# Date: Feb 23rd, 2014                                                             #
-# Version: 1.1.0                                                                   #
+# Date: Jul 8th, 2014                                                              #
+# Version: 1.4.0                                                                   #
 #----------------------------------------------------------------------------------#
 
-slim.dantzig.ladm.scr <- function(Y, X, lambda, nlambda, n, d, maxdf, rho, max.ite, prec, intercept)
+slim.dantzig.ladm.scr <- function(Y, X, lambda, nlambda, n, d, maxdf, rho, max.ite, prec, intercept, verbose)
 {
-  cat("Dantzig selector.\n")
+  if(verbose==TRUE)
+    cat("Dantzig selector with screening.\n")
   XY = crossprod(X,Y/n)
   XX = crossprod(X,X/n)#+0.05*lambda[nlambda]*diag(d)
   beta = matrix(0,nrow=d,ncol=nlambda)
@@ -30,7 +31,7 @@ slim.dantzig.ladm.scr <- function(Y, X, lambda, nlambda, n, d, maxdf, rho, max.i
     num.scr2 = n-1
   }
 
-  order0 = order(XY,decreasing = TRUE)
+  order0 = order(abs(XY),decreasing = TRUE)
   idx.scr = order0; num.scr = length(idx.scr)
   idx.scr1 = order0[1:num.scr1]
   idx.scr2 = order0[1:num.scr2]
